(* $Workfile:   p772.xv2  $ $Revision:   1.0  $ *)

(*****************************************************************************)
(* ASN.1 P42  DATA-TYPE TEMPLATE                                             *)
(*                                                                           *)
(* - Defines: Message Security Protocol extensions to X.400                  *)
(*                                                                           *)
(*****************************************************************************)

MessageSecurityProtocol    LABEL     = 4apdu
                           STRUCTURE = CHOICE
                           CHILDREN  = { <4mspm, C  0 C,O,0>,
                                         <4sgdm, C  1 C,O,0> }

(*****************************************************************************)
(* MSP                                                                       *)
(*****************************************************************************)

signedMsp                  LABEL     = 4sgdm
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <4mspm, U 16 C,M,0>,
                                         <45ali, U 16 C,M,0>,
                                         <45enc, U  3 P,M,0> D}


Msp                        LABEL     = 4mspm
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <4orsd, C  0 C,O,0>  ,
                                         <4sblk, C  1 C,O,0>  ,
                                         <4rcsd, C  2 C,O,0> D,
                                         <4ctds, C  3 S,O,0>  ,
                                         <4mlci, U  0 P,O,0>  ,   MSP 3 only
                                         <4ssal, C  6 C,O,0>  ,   MSP 3 only
                                         <4mleh, C 10 C,O,0>  ,   MSP 4 only
                                         <4adsg, C 13 C,O,0>  ,   MSP 4 only
                                         <4exts, C 12 C,O,0>  ,   MSP 4 only
                                         <45cpt, C  7 C,O,0> D,
                                         <4acpt, C 14 C,O,0>  ,   MSP 4 only
                                         <4enct, C  8 S,O,0> D}


(*****************************************************************************)
(* Originator Security Data                                                  *)
(* (this is a SEQ, treat as ANY as we don't care about it)                   *)
(*****************************************************************************)

originatorSecurityData     LABEL     = 4orsd
                           STRUCTURE = ANY
                           TAG       = (C 0 C)
                           CHILDREN  = {}


(*****************************************************************************)
(* Signature Block                                                           *)
(*****************************************************************************)
signatureBlock             LABEL     = 4sblk
                           STRUCTURE = SEQUENCE
                           TAG       = (C 1 C)
                           CHILDREN  = { <45ali, U 16 C,M,0> D,
                                         <4sgvl, U  4 S,M,0> D,
                                         <4ctrl, U  0 P M,0>  ,
                                         <43scp, U 16 C,O,0> D,
                                         <45scp, C  0 C,O,0> D}


signatureValue             LABEL     = 4sgvl
                           STRUCTURE = OCTETSTRING


controlInformation         LABEL     = 4ctrl
                           STRUCTURE = CHOICE
                           CHILDREN  = { <4sgin, C  0 C,O,0>,
                                         <4rcin, C  1 C,O,0> }

(*****************************************************************************)
(* Signature Information                                                     *)
(*****************************************************************************)
signatureInformation       LABEL     = 4sgin
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <4cntt, U  0 P,O,0> D,
                                         <4sgci, U  4 S,M,0>  ,
                                         <4rcrq, U  0 P M,0> D,
                                         <4rcto, U  0 P,O,0> D}

(*****************************************************************************)
(* Receipt Information                                                       *)
(*****************************************************************************)
receiptInformation         LABEL     = 4rcin
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <4cntt, U  0 P,O,0> D,
                                         <4sgci, U  4 S,M,0>  ,
                                         <4orsg, U  4 S,O,0> D}


signedContentID            LABEL     = 4sgci
                           STRUCTURE = OCTETSTRING

origSignatureValue         LABEL     = 4orsg
                           STRUCTURE = OCTETSTRING


receiptRequests            LABEL     = 4rcrq
                           STRUCTURE = CHOICE
                           CHILDREN  = { <4aorn, C  0 P,O,0>,
                                         <4olrc, C  1 C,O,0>,
                                         <4rcls, C  2 C,O,0> }

receiptsTo                 LABEL     = 4rcto
                           STRUCTURE = ANY
                           CHILDREN  = {}

allOrNone                  LABEL     = 4aorn
                           STRUCTURE = INTEGER

oldReceiptList             LABEL     = 4olrc
                           STRUCTURE = ANY
                           TAG       = (C 1 C)
                           CHILDREN  = {}

receiptList                LABEL     = 4rcls
                           STRUCTURE = ANY
                           TAG       = (C 2 C)
                           CHILDREN  = {}


(*****************************************************************************)
(* Recipient Security Data                                                   *)
(* (this is a SET OF, treat as an ANY as we don't care about it)             *)
(*****************************************************************************)
recipientSecurityData      LABEL     = 4rcsd
                           STRUCTURE = ANY
                           TAG       = (C 2 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* Content Description                                                       *)
(*****************************************************************************)
contentDescription         LABEL     = 4ctds
                           STRUCTURE = TELETEX STRING

(*****************************************************************************)
(* ml Control Information  MSP 3 ONLY                                        *)
(* (this is a CHOICE, treat as an ANY as we don't care about it)             *)
(*****************************************************************************)
mlControlInformation       LABEL     = 4mlci
                           STRUCTURE = CHOICE
                           CHILDREN  = { <4tokn, C  9 C,O,0>,
                                         <4hist, C 10 C,O,0> }

recipMLKeyDistToken        LABEL     = 4tokn
                           STRUCTURE = ANY
                           CHILDREN  = {}

mlExpansionHistory         LABEL     = 4hist
                           STRUCTURE = ANY
                           CHILDREN  = {}

(*****************************************************************************)
(* msp Sequence Signature Algorithm MSP 3 only                               *)
(* (treat as an ANY as we don't care about it)                               *)
(*****************************************************************************)
mspSeqSignatureAlgorithm   LABEL     = 4ssal
                           STRUCTURE = ANY
                           TAG       = (C 6 C)
                           CHILDREN  = {}


(*****************************************************************************)
(* Minimal Algorithm ID and Encryption definitions                           *)
(*****************************************************************************)
AlgorithmIdentifier        LABEL     = 45ali
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <45alg, U  6 P,M,0> D,
                                         <45prm, U  0 P,O,0> }

algorithm                  LABEL     = 45alg
                           STRUCTURE = OBJECT IDENTIFIER

parameters                 LABEL     = 45prm
                           STRUCTURE = ANY
                           CHILDREN  = {}

ENCRYPTED                  LABEL     = 45enc
                           STRUCTURE = BITSTRING

(*****************************************************************************)
(* Certification Path that we don't call back on                             *)
(* (treat as an ANY as we don't care about it)                               *)
(*****************************************************************************)
CertificationPath          LABEL     = 45cpt
                           STRUCTURE = ANY
                           TAG       = (C 7 C)
                           CHILDREN  = {}

CertificationPathSigMSP3   LABEL     = 43scp
                           STRUCTURE = ANY
                           TAG       = (U 16 C)
                           CHILDREN  = {}

CertificationPathSig       LABEL     = 45scp
                           STRUCTURE = ANY
                           TAG       = (C 0 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* ml Expansion History MSP 4 ONLY                                           *)
(* (this is a SEQUENCE OF MlData, treat as ANY as we don't care about it)    *)
(*****************************************************************************)
mlExpansionHistory         LABEL     = 4mleh
                           STRUCTURE = ANY
                           TAG       = (C 10 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* AttributeCertificationPath MSP 4 ONLY                                     *)
(* (this is a SEQUENCE OF AttributeCertificationPath,                        *)
(* treat as ANY as we don't care about it)                                   *)
(*****************************************************************************)
AttributeCertificationPath LABEL     = 4acpt
                           STRUCTURE = ANY
                           TAG       = (C 14 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* additional Signatures MSP 4 ONLY                                          *)
(* (this is a SEQUENCE OF AddSignature,                                      *)
(* treat as ANY as we don't care about it)                                   *)
(*****************************************************************************)
additionalSignatures       LABEL     = 4adsg
                           STRUCTURE = ANY
                           TAG       = (C 13 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* extensions            MSP 4 ONLY                                          *)
(* (this is a SEQUENCE OF Extension,                                         *)
(* treat as ANY as we don't care about it)                                   *)
(*****************************************************************************)
extensions                 LABEL     = 4exts
                           STRUCTURE = ANY
                           TAG       = (C 12 C)
                           CHILDREN  = {}

(*****************************************************************************)
(* Encapsulated Content                                                      *)
(*****************************************************************************)
encapsulatedContent        LABEL     = 4enct
                           STRUCTURE = OCTETSTRING



(*****************************************************************************)
(* MspContentType                                                            *)
(*****************************************************************************)
mspContentType             LABEL     = 4cntt
                           STRUCTURE = CHOICE
                           CHILDREN  = { <4ctbi, A  6 P,O,0> D,
                                         <4ctex, U  6 P,O,0> D,
                                         <4ctes, U 16 C,O,0> D}


BuiltinContentType         LABEL     = 4ctbi
                           STRUCTURE = INTEGER
                           TAG       = (A 6 P)

ExternalContentType        LABEL     = 4ctex
                           STRUCTURE = OBJECT IDENTIFIER

ExternalContentWithSubtype LABEL     = 4ctes
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <4ctex, U  6 P,O,0> D,
                                         <4subt, U  2 P,O,0> D}

Subtype                    LABEL     = 4subt
                           STRUCTURE = INTEGER


(*****************************************************************************)
(* Dummy ANY node                                                            *)
(*****************************************************************************)
dummyAny                   LABEL     = 4dany
                           STRUCTURE = ANY
                           CHILDREN  = {}

!
